#
# spec file for package asus-nb-ctrl
#
# Copyright (c) 2020-2021 Luke Jones <luke@ljones.dev>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

%if %{defined fedora}
%global debug_package %{nil}
%endif

%if "%{_vendor}" != "debbuild"
%global rpm_dkms_opt 1
%endif

# Use hardening ldflags.
%global rustflags -Clink-arg=-Wl,-z,relro,-z,now
Name:           asusctl
Version:        4.0.6
Release:        0
Summary:        Control fan speeds, LEDs, graphics modes, and charge levels for ASUS notebooks
License:        MPLv2

%if "%{_vendor}" == "debbuild"
# Group tag maps to "Section" in debian/control
Group:          kernel
# Packager tag maps to "Maintainer" in debian/control
Packager:       Luke Jones <luke@ljones.dev>
%else
Group:          System Environment/Kernel
%endif
Obsoletes:      asus-nb-ctrl
Requires:       supergfxctl

URL:            https://gitlab.com/asus-linux/asusctl
Source:         https://gitlab.com/asus-linux/asusctl/-/archive/%version/%{name}-%{version}.tar.gz
Source1:        vendor-%{version}.tar.xz

BuildRequires:  cargo

%if "%{_vendor}" == "debbuild"
BuildRequires:  systemd-deb-macros
BuildRequires:  rustc
BuildRequires:  llvm
BuildRequires:  libclang-dev
BuildRequires:  libudev-dev
BuildRequires:  pkg-config

%else
BuildRequires:  systemd-rpm-macros
BuildRequires:  clang-devel
BuildRequires:  rust
BuildRequires:  rust-std-static
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libudev)
%endif

%description
asus-nb-ctrl is a utility for Linux to control many aspects of various
ASUS laptops but can also be used with non-Asus laptops with reduced features.

It provides an interface for rootless control of some system functions such as
fan speeds, keyboard LEDs, battery charge level, and graphics modes.
asus-nb-ctrl enables third-party apps to use the above with dbus methods.

%prep
%autosetup
%if "%{_vendor}" == "debbuild"
tar -xf %{Source1}
%else
%setup -D -T -a 1
%endif

mkdir .cargo
cat >.cargo/config <<EOF
[source.crates-io]
replace-with = "vendored-sources"

[source.vendored-sources]
directory = "vendor"
EOF

%build
export RUSTFLAGS="%{rustflags}"
RUST_BACKTRACE=1 cargo build --release

%install
export RUSTFLAGS="%{rustflags}"

mkdir -p "%{buildroot}%{_bindir}"
install -D -m 0755 target/release/asusd %{buildroot}%{_bindir}/asusd
install -D -m 0755 target/release/asusd-user %{buildroot}%{_bindir}/asusd-user
install -D -m 0755 target/release/asusctl %{buildroot}%{_bindir}/asusctl
install -D -m 0755 target/release/asus-notify %{buildroot}%{_bindir}/asus-notify
install -D -m 0644 data/asusd.rules %{buildroot}%{_udevrulesdir}/90-asusd.rules
install -D -m 0644 data/asusd.conf  %{buildroot}%{_sysconfdir}/dbus-1/system.d/asusd.conf
install -D -m 0644 data/asusd.service %{buildroot}%{_unitdir}/asusd.service
install -D -m 0644 data/asus-notify.service %{buildroot}%{_userunitdir}/asus-notify.service
install -D -m 0644 data/asusd-ledmodes.toml  %{buildroot}%{_sysconfdir}/asusd/asusd-ledmodes.toml
install -D -m 0644 data/icons/asus_notif_yellow.png %{buildroot}%{_datadir}/icons/hicolor/512x512/apps/asus_notif_yellow.png
install -D -m 0644 data/icons/asus_notif_green.png %{buildroot}%{_datadir}/icons/hicolor/512x512/apps/asus_notif_green.png
install -D -m 0644 data/icons/asus_notif_red.png %{buildroot}%{_datadir}/icons/hicolor/512x512/apps/asus_notif_red.png

install -D -m 0644 LICENSE %{buildroot}%{_datadir}/licenses/%{name}/LICENSE
install -D -m 0644 README.md %{buildroot}%{_datadir}/doc/%{name}/README.md
install -D -m 0644 rog-anime/README.md %{buildroot}%{_datadir}/doc/%{name}/README-anime.md
install -D -m 0644 rog-anime/data/diagonal-template.png %{buildroot}%{_datadir}/doc/%{name}/diagonal-template.png

cd rog-anime/data && find "./anime" -type f -exec install -Dm 755 "{}" "%{buildroot}%{_datadir}/asusd/{}" \;
cd ../..

%files
%license LICENSE
%{_bindir}/asusd
%{_bindir}/asusd-user
%{_bindir}/asusctl
%{_bindir}/asus-notify
%{_unitdir}/asusd.service
%{_userunitdir}/asus-notify.service
%{_udevrulesdir}/90-asusd.rules
%{_sysconfdir}/dbus-1/system.d/asusd.conf
%dir %{_sysconfdir}/asusd/
%{_sysconfdir}/asusd/asusd-ledmodes.toml
%dir %{_datadir}/icons
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/512x512
%dir %{_datadir}/icons/hicolor/512x512/apps
%{_datadir}/icons/hicolor/512x512/apps/asus_notif_yellow.png
%{_datadir}/icons/hicolor/512x512/apps/asus_notif_green.png
%{_datadir}/icons/hicolor/512x512/apps/asus_notif_red.png
%dir %{_datadir}/doc
%dir %{_datadir}/doc/%{name}
%{_datadir}/doc/%{name}/*
%dir %{_datadir}/asusd
%{_datadir}/asusd/*

%changelog
